using System;
using System.Text;
using System.Collections.Generic;
using Linaware.Flybox;
using System.Net;
using System.Linq;
using System.Xml.Linq;
using System.IO;
using System.Threading;
	
namespace MaSociete.MonProjet.Tracabilite
{
	
	public class Tracabilite
	{
        /// <summary>
		/// FlyModule script
        /// </summary>
		FlyModule module = null;

        /// <summary>
		/// Accès au fichier de configuration "module.xml" du module
        /// </summary>
		ConfigHelper config = null;

        /// <summary>
        /// Thread de surveillance des événements de traçabilité
        /// </summary>
        Thread threadTraitement;

        /// <summary>
        /// Chargement du module
        /// </summary>
		public  void Load(FlyModule module, ConfigHelper config)
		{
			this.module = module;
			this.config = config;
			
			// Création d'un fil de traitement
            threadTraitement = new Thread(new ThreadStart(traitement));
            threadTraitement.Start();

		}

        /// <summary>
        /// Arrêt du module
        /// </summary>
		public  void Quit()
		{
			// Arrêt du fil de traitement
			if (threadTraitement != null)
				threadTraitement.Abort();
		}

        /// <summary>
        /// Fonction associée au file de traitement
        /// </summary>
        void traitement()
        {
            try
            {
				module.Trace(TRACETYPE.INFO, "Démarrage du fil de traitement");
				bool firstCycle = true;
				
				while(true)
				{
					try
					{
						if (firstCycle)
							module.Trace(TRACETYPE.INFO, "Premier cycle su script ...");

					}
					catch (Exception ex)
					{
						module.Trace(TRACETYPE.ERROR, ex.Message);
						module.Trace(TRACETYPE.ERROR, ex.StackTrace); 
					}

                    firstCycle = false;
					Thread.Sleep(1000);
				}
			}
            catch (ThreadAbortException)
            {
                // Arrêt normal du thread
            }
            catch (Exception ex)
            {
                module.Trace(TRACETYPE.ERROR, "Erreur générale dans traitement, arrêt du thread !");
                module.Trace(TRACETYPE.ERROR, ex.Message);
                module.Trace(TRACETYPE.ERROR, ex.StackTrace); 
            }
		}
			
	}

}